use lazy_static::lazy_static;
use std::collections::HashSet;

lazy_static! {
    /// A static HashSet containing non-imperative verb forms common to commit messages.
    pub static ref NON_IMPERATIVE_VERBS: HashSet<&'static str> = {
        vec![
            "added",
            "adding",
            "adds",
            "allowed",
            "allowing",
            "allows",
            "appended",
            "appending",
            "appends",
            "attached",
            "attaches",
            "attaching",
            "automated",
            "automates",
            "automating",
            "balanced",
            "balances",
            "balancing",
            "building",
            "builds",
            "built",
            "bumped",
            "bumping",
            "bumps",
            "cached",
            "caches",
            "caching",
            "calculated",
            "calculates",
            "calculating",
            "changes",
            "changing",
            "checked",
            "checking",
            "checks",
            "clarified",
            "clarifies",
            "clarifying",
            "cleaned",
            "cleaning",
            "cleans",
            "cloned",
            "clones",
            "cloning",
            "compared",
            "compares",
            "comparing",
            "compiled",
            "compiles",
            "compiling",
            "composed",
            "composes",
            "composing",
            "compressed",
            "compresses",
            "compressing",
            "computed",
            "computes",
            "computing",
            "configured",
            "configures",
            "configuring",
            "consolidated",
            "consolidates",
            "consolidating",
            "copied",
            "copies",
            "copying",
            "corrected",
            "correcting",
            "corrects",
            "created",
            "creates",
            "creating",
            "decrypted",
            "decrypting",
            "decrypts",
            "deleted",
            "deletes",
            "deleting",
            "deployed",
            "deploying",
            "deploys",
            "deprecated",
            "deprecates",
            "deprecating",
            "determined",
            "determines",
            "determining",
            "disabled",
            "disables",
            "disabling",
            "dispatched",
            "dispatches",
            "dispatching",
            "displayed",
            "displaying",
            "displays",
            "documented",
            "documenting",
            "documents",
            "enabled",
            "enables",
            "enabling",
            "encrypted",
            "encrypting",
            "encrypts",
            "enforced",
            "enforces",
            "enforcing",
            "enhanced",
            "enhances",
            "enhancing",
            "evaluated",
            "evaluates",
            "evaluating",
            "extracted",
            "extracting",
            "extracts",
            "fixed",
            "fixes",
            "fixing",
            "freed",
            "freeing",
            "frees",
            "generated",
            "generates",
            "generating",
            "handled",
            "handles",
            "handling",
            "hidden",
            "hides",
            "hiding",
            "ignored",
            "ignores",
            "ignoring",
            "implemented",
            "implementing",
            "implements",
            "improved",
            "improves",
            "improving",
            "indexed",
            "indexes",
            "indexing",
            "initialised",
            "initialises",
            "initialising",
            "initialized",
            "initializes",
            "initializing",
            "initiated",
            "initiates",
            "initiating",
            "installed",
            "installing",
            "installs",
            "introduced",
            "introduces",
            "introducing",
            "invoked",
            "invokes",
            "invoking",
            "linted",
            "linting",
            "lints",
            "loaded",
            "loading",
            "loads",
            "logged",
            "made",
            "makes",
            "making",
            "merged",
            "merges",
            "merging",
            "migrated",
            "migrates",
            "migrating",
            "moved",
            "moves",
            "moving",
            "optimised",
            "optimises",
            "optimising",
            "optimized",
            "optimizes",
            "optimizing",
            "permits",
            "permitted",
            "permitting",
            "polished",
            "polishes",
            "polishing",
            "populated",
            "populates",
            "populating",
            "prepended",
            "prepending",
            "prepends",
            "prevented",
            "preventing",
            "prevents",
            "pulled",
            "pulling",
            "pulls",
            "purged",
            "purges",
            "purging",
            "pushed",
            "pushes",
            "pushing",
            "reading",
            "reads",
            "rebased",
            "rebases",
            "rebasing",
            "rebuilding",
            "rebuilds",
            "rebuilt",
            "reduced",
            "reduces",
            "reducing",
            "reduplicated",
            "reduplicates",
            "reduplicating",
            "refactored",
            "refactoring",
            "refactors",
            "released",
            "releases",
            "releasing",
            "removed",
            "removes",
            "removing",
            "replaced",
            "replaces",
            "replacing",
            "retrieved",
            "retrieves",
            "retrieving",
            "reverted",
            "reverting",
            "reverts",
            "reviewed",
            "reviewing",
            "reviews",
            "scaled",
            "scales",
            "scaling",
            "serialized",
            "serializes",
            "serializing",
            "sets",
            "setting",
            "simplified",
            "simplifies",
            "simplifying",
            "skipped",
            "skipping",
            "skips",
            "sorted",
            "sorting",
            "sorts",
            "specified",
            "specifies",
            "specifying",
            "started",
            "starting",
            "starts",
            "stopped",
            "stopping",
            "stops",
            "styled",
            "styles",
            "styling",
            "supported",
            "supporting",
            "supports",
            "swapped",
            "swapping",
            "swaps",
            "synched",
            "synching",
            "synchronised",
            "synchronises",
            "synchronising",
            "synchronized",
            "synchronizes",
            "synchronizing",
            "synchs",
            "terminated",
            "terminates",
            "terminating",
            "tested",
            "testing",
            "tests",
            "threw",
            "throwing",
            "thrown",
            "translated",
            "translates",
            "translating",
            "truncated",
            "truncates",
            "truncating",
            "turned",
            "turning",
            "turns",
            "unified",
            "unifies",
            "unifying",
            "updated",
            "updates",
            "updating",
            "upgraded",
            "upgrades",
            "upgrading",
            "used",
            "uses",
            "using",
            "validated",
            "validates",
            "validating",
            "whitelisted",
            "whitelisting",
            "whitelists",
            "wrapped",
            "wrapping",
            "wraps",
        ]
        .into_iter()
        .collect()
    };
}
